
# StarSearch
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/jdavidrcamacho/tedi/blob/master/LICENSE)

### Examples

`workshop.ipynb` - jupyter notebook explaning the main functions of StarSearch

`starExample.py` - python script with more examples

----------
<img align="right" width="180" height="180" src="https://i.imgur.com/yhIts2Y.png">
